@@ -3,7 +3,12 @@ The module creation includes classes to create new variables by combination of e
 variables in the dataframe.
 """
 
-from .mathematical_combination import MathematicalCombination
 from .combine_with_reference_feature import CombineWithReferenceFeature
+from .cyclical import CyclicalTransformer
+from .mathematical_combination import MathematicalCombination
 
-__all__ = ["MathematicalCombination", "CombineWithReferenceFeature"]
+__all__ = [
+    "MathematicalCombination",
+    "CombineWithReferenceFeature",
+    "CyclicalTransformer",
+]
